@@ -3,6 +3,7 @@ from treex import types
 from .batch_norm import BatchNorm
 from .conv import Conv
 from .dropout import Dropout
+from .embed import Embed
 from .flatten import Flatten
 from .flax_module import FlaxModule
 from .linear import Linear
@@ -11,13 +12,16 @@ from .sequential import Lambda, Sequential, sequence
 
 try:
     from .haiku_module import HaikuModule
+
+    _haiku_available = True
 except types.OptionalDependencyNotFound:
-    pass
+    _haiku_available = False
 
 __all__ = [
     "BatchNorm",
     "Conv",
     "Dropout",
+    "Embed",
     "Flatten",
     "FlaxModule",
     "Linear",
@@ -25,5 +29,7 @@ __all__ = [
     "Lambda",
     "Sequential",
     "sequence",
-    "HaikuModule",
 ]
+
+if _haiku_available:
+    __all__.append("HaikuModule")
